==> n3_sdk-1.3.1r03.zip: n3_sdk-1.3.1/lib/default/Design-1.2.0-min.js <==

var Design={PREFIX_LIST:{"Webkit":"-webkit-","Moz":"-moz-","O":"-o-","ms":"-ms-","Ms":"-ms-"},CAPREX:new RegExp("-[a-z]","g"),capitalize:function(src){return src.replace(this.CAPREX,function(s){return s.charAt(1).toUpperCase();});},_sheet:null,_o2ss:function(sel,o){var rss=[];for(var k in o){var rkey=this.getRealKey(k);if(rkey){var v=o[k];if(!(v instanceof Array)){v=[v];}
for(var i=0,_v;_v=v[i];i++){rss.push(rkey+":"+_v+";");}}}
return sel+"{"+rss.join(" ")+"}";},cast:function(so){var rls=[];for(var k in so){rls.push(this._o2ss(k,so[k]));}
var sheet=this._sheet;var rules=this._sheet.cssRules;var tp=rules.length,p=tp;for(var i=0,sz=rls.length;i<sz;i++){sheet.insertRule(rls[i],p++);}
return rules},castWithMedia:function(mi,so,ml){var rls="";for(var k in so){rls+=this._o2ss(k,so[k]);}
rls="@media "+mi+"{"+rls+"}";var sheet=this._sheet;var rules=this._sheet.cssRules;sheet.insertRule(rls,rules.length);if(ml){var mql=matchMedia(mi);mql.addListener(ml);}
return rules},shutdown:function(){Design=void(0);},PROPS:{},VP:"",_unks:null,_CE:null,getProperty:function(src,e){var r=this.PROPS[src];if(r){return r;}
var style=(e||this._CE).style;var n=this.capitalize(src);if(n in style){this.PROPS[src]=n;return n;}
var vp=this.VP;if(vp){var nc=this._testPrefix(style,n,vp);if(nc){this.PROPS[src]=nc;return nc;}}
else{var prefixes=Object.keys(this.PREFIX_LIST);for(var i=0,sz=prefixes.length;i<sz;i++){var _ps=prefixes[i];var nc=this._testPrefix(style,n,_ps);if(nc){this.PROPS[src]=nc;this.VP=_ps;return nc;}}}
var unks=this._unks;if(unks){unks[src]=true;}
return src;},_testPrefix:function(style,n,ps){var nc=ps+(n.charAt(0)).toUpperCase()+n.substring(1);return(nc in style)?nc:null;},getRealKey:function(src,e){var r=this.PREFIXED[src];if(r){return r;}
var style=(e||this._CE).style;var n=this.capitalize(src);if(n in style){this.PREFIXED[src]=src;return src;}
var pf_list=this.PREFIX_LIST;var vp=this.VP;if(vp){var nc=vp+(n.charAt(0)).toUpperCase()+n.substring(1);if(nc in style){var rk=pf_list[vp]+src;this.PREFIXED[src]=rk;return rk}}
else{for(var _ps in pf_list){var nc=_ps+(n.charAt(0)).toUpperCase()+n.substring(1);if(nc in style){var rk=pf_list[_ps]+src;this.PREFIXED[src]=rk;this.VP=_ps;return rk}}}
var unks=this._unks;if(unks){unks[src]=true;}
return src;},PREFIXED:{},getStyle:function(e){return document.defaultView.getComputedStyle(e);},getValue:function(e,key){return(this.getStyle(e))[key];},init:function(doc){var sheet=this._sheet;if(sheet){var owner=sheet.ownerNode;owner.parentNode.removeChild(owner);}
doc=doc||window.document;var so=doc.createElement("style");doc.head.appendChild(so);this._sheet=so.sheet;var ce=doc.body||doc.documentElement;ce.style.float="";this._CE=ce;return this;},create:function(s){var so=document.createElement("style");so.textContent=s;window.document.head.appendChild(so);return so;},remove:function(r){var sheet=r.parentStyleSheet;var rls=sheet.cssRules;for(var i=0,sz=rls.length;i<sz;i++){if(r===rls.item(i)){sheet.deleteRule(r,i);return;}}},enableDebugging:function(b){if(!b){this._unks=null;}
else if(!this._unks){this._unks={};}},fetchUnknowns:function(){var unks=this._unks;if(unks){this._unks={};return Object.keys(unks);}
return[];}}.init();Object.defineProperty(window,"Design",{writable:false,configurable:false});

==> n3_sdk-1.3.3r03.zip: n3_sdk-1.3.3/lib/default/Design-1.2.0-min.js <==

var Design={PREFIX_LIST:{"Webkit":"-webkit-","Moz":"-moz-","O":"-o-","ms":"-ms-","Ms":"-ms-"},CAPREX:new RegExp("-[a-z]","g"),capitalize:function(src){return src.replace(this.CAPREX,function(s){return s.charAt(1).toUpperCase();});},_sheet:null,_o2ss:function(sel,o){var rss=[];for(var k in o){var rkey=this.getRealKey(k);if(rkey){var v=o[k];if(!(v instanceof Array)){v=[v];}
for(var i=0,_v;_v=v[i];i++){rss.push(rkey+":"+_v+";");}}}
return sel+"{"+rss.join(" ")+"}";},cast:function(so){var rls=[];for(var k in so){rls.push(this._o2ss(k,so[k]));}
var sheet=this._sheet;var rules=this._sheet.cssRules;var tp=rules.length,p=tp;for(var i=0,sz=rls.length;i<sz;i++){sheet.insertRule(rls[i],p++);}
return rules},castWithMedia:function(mi,so,ml){var rls="";for(var k in so){rls+=this._o2ss(k,so[k]);}
rls="@media "+mi+"{"+rls+"}";var sheet=this._sheet;var rules=this._sheet.cssRules;sheet.insertRule(rls,rules.length);if(ml){var mql=matchMedia(mi);mql.addListener(ml);}
return rules},shutdown:function(){Design=void(0);},PROPS:{},VP:"",_unks:null,_CE:null,getProperty:function(src,e){var r=this.PROPS[src];if(r){return r;}
var style=(e||this._CE).style;var n=this.capitalize(src);if(n in style){this.PROPS[src]=n;return n;}
var vp=this.VP;if(vp){var nc=this._testPrefix(style,n,vp);if(nc){this.PROPS[src]=nc;return nc;}}
else{var prefixes=Object.keys(this.PREFIX_LIST);for(var i=0,sz=prefixes.length;i<sz;i++){var _ps=prefixes[i];var nc=this._testPrefix(style,n,_ps);if(nc){this.PROPS[src]=nc;this.VP=_ps;return nc;}}}
var unks=this._unks;if(unks){unks[src]=true;}
return src;},_testPrefix:function(style,n,ps){var nc=ps+(n.charAt(0)).toUpperCase()+n.substring(1);return(nc in style)?nc:null;},getRealKey:function(src,e){var r=this.PREFIXED[src];if(r){return r;}
var style=(e||this._CE).style;var n=this.capitalize(src);if(n in style){this.PREFIXED[src]=src;return src;}
var pf_list=this.PREFIX_LIST;var vp=this.VP;if(vp){var nc=vp+(n.charAt(0)).toUpperCase()+n.substring(1);if(nc in style){var rk=pf_list[vp]+src;this.PREFIXED[src]=rk;return rk}}
else{for(var _ps in pf_list){var nc=_ps+(n.charAt(0)).toUpperCase()+n.substring(1);if(nc in style){var rk=pf_list[_ps]+src;this.PREFIXED[src]=rk;this.VP=_ps;return rk}}}
var unks=this._unks;if(unks){unks[src]=true;}
return src;},PREFIXED:{},getStyle:function(e){return document.defaultView.getComputedStyle(e);},getValue:function(e,key){return(this.getStyle(e))[key];},init:function(doc){var sheet=this._sheet;if(sheet){var owner=sheet.ownerNode;owner.parentNode.removeChild(owner);}
doc=doc||window.document;var so=doc.createElement("style");doc.head.appendChild(so);this._sheet=so.sheet;var ce=doc.body||doc.documentElement;ce.style.float="";this._CE=ce;return this;},create:function(s){var so=document.createElement("style");so.textContent=s;window.document.head.appendChild(so);return so;},remove:function(r){var sheet=r.parentStyleSheet;var rls=sheet.cssRules;for(var i=0,sz=rls.length;i<sz;i++){if(r===rls.item(i)){sheet.deleteRule(r,i);return;}}},enableDebugging:function(b){if(!b){this._unks=null;}
else if(!this._unks){this._unks={};}},fetchUnknowns:function(){var unks=this._unks;if(unks){this._unks={};return Object.keys(unks);}
return[];}}.init();Object.defineProperty(window,"Design",{});
